# Random Dot Pattern

Display static colored dots.

## Example: Psychophysics

Two random dot patterns are shown. The participant is asked to press 'y' the number of dots in the right pattern is not equal to the number of dots in the left pattern and 'n' if they are the same.

![weber fechner](../../img/stimuli/weber_fechner.png)